#!/usr/bin/env bash
set -e

DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")"; pwd)"
HERE="$(pwd)"

function help
{
	echo "Usage: ${BASH_SOURCE[0]} <Mesa src rpm URL>"
	echo
	echo "Example:"
	echo
	echo "${BASH_SOURCE[0]} http://distrib-coffee.ipsl.jussieu.fr/pub/linux/Mageia/distrib/9/SRPMS/core/release/mesa-23.1.5-2.mga9.src.rpm"
	echo
}

function die
{
	echo "$1" >&2
	help
	exit 1
}

SUDO=''
if [ $(id -u) -ne 0 ]; then
	if ! command -v sudo > /dev/null 2>&1; then
		die "Please install sudo or run as root"
	fi
	SUDO='sudo'
fi

URL="$1"
[ -n "${URL}" ] || die "Please provide URL of Mesa source RPM"

LINUX_ARCH="$(uname -m)"
case "${LINUX_ARCH}" in
	i686)
		PKG_ARCH=i586
		LIB_PKG_NAME=libdri-drivers
		;;
	x86_64)
		PKG_ARCH=x86_64
		LIB_PKG_NAME=lib64dri-drivers
		;;
	armv7l)
		PKG_ARCH=armv7l
		LIB_PKG_NAME=libdri-drivers
		;;
	aarch64)
		PKG_ARCH=aarch64
		LIB_PKG_NAME=lib64dri-drivers
		;;
	*)
		die "Unsupported architecture ${LINUX_ARCH}"
		;;
esac

unset WORKDIR

function cleanup
{
	[ -z "${WORKDIR}" ] || [ ! -d "${WORKDIR}" ] || rm -rf "${WORKDIR}" ]
	cd "${HERE}"
}

trap cleanup EXIT

echo "Creating a temporary working directory..."
WORKDIR="$(realpath "$(mktemp -d --tmpdir tmp.XXXX)")"
mkdir -p "${WORKDIR}"/rpmbuild/{BUILD,BUILDROOT,RPMS,SOURCES,SPECS,SRPMS}
cd "${WORKDIR}"
mkdir "${WORKDIR}/orig.src"
cd "${WORKDIR}/orig.src"
echo "Getting and patching source RPM..."
curl "${URL}" | rpm2cpio | cpio -idmv
patch -p1 < "${DIR}/mesa.spec.patch"
cp *.patch *.sh *.tar.xz "${WORKDIR}/rpmbuild/SOURCES"
cp mesa.spec "${WORKDIR}/rpmbuild/SPECS"
echo "Installing building dependencies..."
${SUDO} urpmi --buildrequires "${WORKDIR}/rpmbuild/SPECS/mesa.spec"
echo "Building RPM packages..."
rpmbuild --define "_topdir ${WORKDIR}/rpmbuild" --define='distro_section tainted' -ba "${WORKDIR}/rpmbuild/SPECS/mesa.spec"
cd "${WORKDIR}/rpmbuild/RPMS/${PKG_ARCH}"
for FILE in "${LIB_PKG_NAME}"*.rpm; do
	if [ -f "${FILE}" ]; then
		echo "${FILE} has been successfully built"
		mv -f "${FILE}" "${HERE}"
	fi
done
