#!/usr/bin/env bash
set -e

DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")"; pwd)"
HERE="$(pwd)"

SUDO=''
if [ $(id -u) -ne 0 ]; then
	if ! command -v sudo > /dev/null 2>&1; then
		die "Please install sudo or run as root"
	fi
	SUDO='sudo'
fi

LINUX_ARCH="$(uname -m)"
case "${LINUX_ARCH}" in
	i686)
		PKG_ARCH=i586
		LIB_PKG_NAME=libdri-drivers
		;;
	x86_64)
		PKG_ARCH=x86_64
		LIB_PKG_NAME=lib64dri-drivers
		;;
	armv7l)
		PKG_ARCH=armv7l
		LIB_PKG_NAME=libdri-drivers
		;;
	aarch64)
		PKG_ARCH=aarch64
		LIB_PKG_NAME=lib64dri-drivers
		;;
	*)
		die "Unsupported architecture ${LINUX_ARCH}"
		;;
esac

MIRROR="${1:-http://distrib-coffee.ipsl.jussieu.fr/pub/linux/Mageia/distrib/9}"
echo "Querying metadata of ${LIB_PKG_NAME} package from ${MIRROR}"
SRC_RPM="$(urpmq -i "${LIB_PKG_NAME}" | grep 'Source RPM' | sed -E -n 's/^Source RPM *: *(.*)$/\1/p' | tail -1)"
VERSION="$(urpmq -i "${LIB_PKG_NAME}" | grep 'Version' | sed -E -n 's/^Version *: *(.*)$/\1/p' | tail -1)"
RELEASE="$(urpmq -i "${LIB_PKG_NAME}" | grep 'Release' | sed -E -n 's/^Release *: *(.*)$/\1/p' | tail -1)"

echo "Source RPM: ${SRC_RPM}"
echo "Version: ${VERSION}"
echo "Release: ${RELEASE}"

[ -n "${SRC_RPM}" ] && [ -n "${VERSION}" ] && [ -n "${RELEASE}" ]

echo "Building package for tainted Mesa DRI drivers"
RELEASE_URL="${MIRROR}/SRPMS/core/release"
UPDATES_URL="${MIRROR}/SRPMS/core/updates"
"${DIR}/build.sh" "${UPDATES_URL}/${SRC_RPM}" || "${DIR}/build.sh" "${RELEASE_URL}/${SRC_RPM}"

if rpm -q "${LIB_PKG_NAME}"; then
	echo "Removing installed package for Mesa DRI drivers"
	${SUDO} rpm --erase --nodeps "${LIB_PKG_NAME}"
fi
echo "Installing package for tainted Mesa DRI drivers"
${SUDO} rpm --install --verbose --nodeps --replacepkgs "${LIB_PKG_NAME}-${VERSION}-${RELEASE}.tainted.${PKG_ARCH}.rpm"
